import { IonContent, IonItem, IonLabel, IonListHeader } from "@ionic/react";
import "../components/ListComponent.css";
import SkeletonText from "./SkeletonText";

/**
 * This component creates a shimmering "skeleton" version of the list component.
 * It shows only when content isn't available yet (loading).
 */
function ListComponentSkeleton({ items = 5 }: { items?: number }) {
  return (
    <>
      {Array(items)
        .fill(0)
        .map((_, i) => (
          <IonItem key={i}>
            <SkeletonText />
          </IonItem>
        ))}
    </>
  );
}

const ListComponent: React.FC<{
  title?: string;
  laws: string[];
  loading?: boolean;
}> = (props) => {
  const title = props.title;
  const laws = props.laws;
  const loading = props.loading ?? false;

  return (
    <IonContent>
      {title ? (
        <IonListHeader>
          <IonLabel>{title}</IonLabel>
        </IonListHeader>
      ) : null}

      {loading && <ListComponentSkeleton />}

      {!loading &&
        laws.map((lawName: string) => {
          return (
            <IonItem
              key={lawName}
              routerLink={`/article/${encodeURIComponent(lawName)}`}
            >
              <p className="ListItemText">{lawName}</p>
            </IonItem>
          );
        })}
    </IonContent>
  );
};
export default ListComponent;
